@@ -1,19 +1,9 @@
 #ifndef AWS_COMMON_ERROR_H
 #define AWS_COMMON_ERROR_H
 
-/*
- * Copyright 2010-2018 Amazon.com, Inc. or its affiliates. All Rights Reserved.
- *
- * Licensed under the Apache License, Version 2.0 (the "License").
- * You may not use this file except in compliance with the License.
- * A copy of the License is located at
- *
- *  http://aws.amazon.com/apache2.0
- *
- * or in the "license" file accompanying this file. This file is distributed
- * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
- * express or implied. See the License for the specific language governing
- * permissions and limitations under the License.
+/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
  */
 
 #include <aws/common/assert.h>
@@ -153,6 +143,7 @@ AWS_EXTERN_C_END
 enum aws_common_error {
     AWS_ERROR_SUCCESS = AWS_ERROR_ENUM_BEGIN_RANGE(AWS_C_COMMON_PACKAGE_ID),
     AWS_ERROR_OOM,
+    AWS_ERROR_NO_SPACE,
     AWS_ERROR_UNKNOWN,
     AWS_ERROR_SHORT_BUFFER,
     AWS_ERROR_OVERFLOW_DETECTED,
